@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.5.0"
+    version = "1.5.1"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -112,13 +112,15 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         issue_link = group.get_absolute_url(params={"referrer": "dingtalknotify"})
         issue_link = issue_link.replace('https', 'http')
 
+        print(123456, type(group))
+
         payload = f"## {custom_keyword}\n\n" if custom_keyword else ""
         payload = f"{payload} > 项目名称: {project.name} \n\n"
         # payload = f"{payload} > status: {group.status} \n\n"
         payload = f"{payload} > 出现次数: {group.times_seen} \n\n"
         payload = f"{payload} > 查看详情: <font color=blue>[{group.title if group.title else 'unknown'}]({issue_link})</font> \n\n"
         payload = f"{payload} > 具体报错: {group.message} \n\n"
-        payload = f"{payload} > 全部报错: {group} \n\n"
+        payload = f"{payload} > 全部报错: {json.dumps(group)} \n\n"
 
         headers = {
             "Content-type": "application/json",
